@@ -8,7 +8,7 @@
 #
 package Dist::Zilla::Plugin::Git::GatherDir;
 {
-  $Dist::Zilla::Plugin::Git::GatherDir::VERSION = '2.012';
+  $Dist::Zilla::Plugin::Git::GatherDir::VERSION = '2.013';
 }
 # ABSTRACT: gather all tracked files in a Git working directory
 use Moose;
@@ -64,6 +64,11 @@ override gather_files => sub {
       for ($self->exclude_filename->flatten);
     next if $file =~ $exclude_regex;
 
+    if (-d $file) {
+      $self->log("WARNING: $file is symlink to directory, skipping it");
+      next;
+    }
+
     push @files, $self->_file_from_filename($filename);
   }
 
@@ -94,7 +99,7 @@ Dist::Zilla::Plugin::Git::GatherDir - gather all tracked files in a Git working
 
 =head1 VERSION
 
-version 2.012
+version 2.013
 
 =head1 DESCRIPTION
 
@@ -160,9 +165,19 @@ one, if any).
 
 =head2 follow_symlinks
 
-By default, directories that are symlinks will not be followed. Note on the
-other hand that in all followed directories, files which are symlinks are
-always gathered.
+Git::GatherDir does not honor GatherDir's
+L<follow_symlinks|Dist::Zilla::Plugin::GatherDir/follow_symlinks>
+option.  While the attribute exists (because Git::GatherDir is a
+subclass), setting it has no effect.
+
+Directories that are symlinks will not be gathered.  Instead, you'll
+get a message saying C<WARNING: %s is symlink to directory, skipping it>.
+To suppress the warning, add that directory to C<exclude_filename> or
+C<exclude_match>.  To gather the files in the symlinked directory, use
+a second instance of GatherDir or Git::GatherDir with appropriate
+C<root> and C<prefix> options.
+
+Files which are symlinks are always gathered.
 
 =head2 exclude_filename
 
